@@ -1,17 +1,17 @@
-import os
-import json
-from pathlib import Path
 from typing import Optional, List, Dict
 from jinja2 import Template
 import logging
-from cdocs.config import Config
-from cdocs.dict_finder import DictFinder
 from cdocs.contextual_docs import Doc, DocPath, FilePath, JsonDict, ContextualDocs
-from cdocs.simple_reader import SimpleReader
-from cdocs.simple_pather import SimplePather
+from cdocs.config import Config
 from cdocs.pather import Pather
 from cdocs.reader import Reader
-
+from cdocs.finder import Finder
+from cdocs.simple_config import SimpleConfig
+from cdocs.simple_reader import SimpleReader
+from cdocs.simple_pather import SimplePather
+from cdocs.simple_finder import SimpleFinder
+from cdocs.simple_filer import SimpleFiler
+from cdocs.physical import Physical
 
 class DocNotFoundException(Exception):
     pass
@@ -23,38 +23,26 @@ class ComposeDocException(Exception):
     pass
 
 
-class Cdocs(ContextualDocs):
+class Cdocs(ContextualDocs, Physical):
 
     def __init__(self, docspath:str, config:Optional[Config]=None):
-        cfg = Config(None) if config is None else config
+        super().__init__()
+        cfg = SimpleConfig(None) if config is None else config
         self._config = cfg
         self._docs_path:str = docspath
         self._ext:str  = cfg.get_with_default("formats", "ext", "xml")
+        self._filer = SimpleFiler()
         self._tokens_filename:str  = cfg.get_with_default("filenames", "tokens", "tokens.json")
         self._labels_filename:str  = cfg.get_with_default("filenames", "labels", "labels.json")
         self._hashmark:str  = cfg.get_with_default("filenames", "hashmark", "#")
         self._plus:str  = cfg.get_with_default("filenames", "plus", "+")
-        self._reader:Reader = SimpleReader()
-        self._pather:Pather = SimplePather(self._docs_path, cfg.get_config_path())
+        self.reader = SimpleReader() if cfg.reader is None else cfg.reader
+        self.finder = SimpleFinder(docspath) if cfg.finder is None else cfg.finder
+        self.pather = SimplePather(self._docs_path, cfg.get_config_path()) if cfg.pather is None else cfg.pather
         logging.info(f"Cdocs.__init__: path: {self._docs_path}, ext: {self._ext}, \
 tokens: {self._tokens_filename}, labels: {self._labels_filename}, \
 hash: {self._hashmark}, plus: {self._plus}")
 
-    @property
-    def reader(self) -> Reader:
-        return self._reader
-
-    @reader.setter
-    def reader(self, reader:Reader) -> None:
-        self._reader = reader
-
-    @property
-    def pather(self) -> Pather:
-        return self._pather
-
-    @pather.setter
-    def pather(self, pather:Pather) -> None:
-        self._pather = pather
 
     def get_doc_root(self) -> FilePath:
         return FilePath(self._docs_path)
@@ -62,6 +50,18 @@ hash: {self._hashmark}, plus: {self._plus}")
     def get_tokens(self, path:DocPath) -> JsonDict:
         return self._get_dict(path, self._tokens_filename)
 
+    @property
+    def filer(self):
+        return self._filer
+
+    @property
+    def config(self):
+        return self._config
+
+# ===================
+# abc methods
+# ===================
+
     def get_labels(self, path:DocPath) -> JsonDict:
         labels = self._get_dict(path, self._labels_filename)
         return self._transform_labels(path, labels)
@@ -91,19 +91,44 @@ hash: {self._hashmark}, plus: {self._plus}")
         return Doc(content)
 
     def get_doc(self, path:DocPath) -> Doc:
+        return self._get_doc(path, True)
+
+    def _get_doc(self, path:DocPath, notfound:Optional[bool]=False) -> Optional[Doc]:
         if path is None :
             raise DocNotFoundException("path can not be None")
         if path.find('.') > -1:
-            raise BadDocPath("dots are not allowed in doc paths")
+            if self.filer.get_filetype(path) == 'cdocs':
+                raise BadDocPath("dots are not allowed in cdoc paths")
         pluspaths = self._get_plus_paths(path)
         root = self.get_doc_root()
-        return self._get_doc_for_root(path, pluspaths, root)
+        doc = self._get_doc_for_root(path, pluspaths, root)
+        if doc is None and notfound:
+           doc = self.get_404()
+        return doc
+
+# ===================
+# internal methods
+# ===================
+
+    def get_404(self) -> Optional[Doc]:
+        config = self.config
+        _404 = config.get_with_default("defaults", "notfound", None)
+        if _404 is None:
+            return None
+        index = _404.find("/")
+        root = _404[0:index]
+        path = _404[index+1:]
+        root = config.get("docs", root)
+        cdocs = Cdocs(root)
+        doc = cdocs._get_doc_for_root(path, [], root)
+        return doc
 
     def _get_doc_for_root(self, path:DocPath, pluspaths:List[DocPath], root:FilePath) -> Doc:
         if len(pluspaths) > 0:
             plus = path.find(self._plus)
             path = path[0:plus]
         filepath = self._pather.get_full_file_path_for_root(path, root)
+        print(f"_get_doc_for_root: {filepath}")
         content = self._read_doc(filepath)
         content = self._transform(content, path, None, True)
         if len(pluspaths) > 0:
@@ -116,20 +141,25 @@ hash: {self._hashmark}, plus: {self._plus}")
         ls = { k:self._transform(v, path, tokens, False) for k,v in labels.items() }
         return JsonDict(ls)
 
-    def _transform(self, content:str, path:Optional[str]=None, tokens:Optional[Dict[str,str]]=None, transform_labels=True) -> str:
+    def _transform(self, content:str, path:DocPath=None, tokens:Optional[Dict[str,str]]=None, transform_labels=True) -> str:
         if content is None:
             logging.info("Cdocs._transform: cannot transform None. returning ''")
             return None
-        if tokens is None and path is None:
-            print(f"Warning: _transform with no path and no tokens")
-            tokens = {}
-        elif tokens is None:
-            tokens:JsonDict = self.get_tokens(path)
-        if path is not None and transform_labels:
-            tokens = self._add_labels_to_tokens(path, tokens)
-        tokens["get_doc"] = self.get_doc
-        template = Template(content)
-        return template.render(tokens)
+        if path is None:
+            raise BadDocPath("you must provide the DocPath")
+        filetype = self.filer.get_filetype(path)
+        if filetype in ['html','concat','cdocs']:
+            if tokens is None:
+                tokens:JsonDict = self.get_tokens(path)
+            if path is not None and transform_labels:
+                tokens = self._add_labels_to_tokens(path, tokens)
+            tokens["get_doc"] = self.get_doc
+            try:
+                template = Template(content)
+                content = template.render(tokens)
+            except Exception as e:
+                logging.info(f"couldn't transform content: {e}")
+        return content
 
     def _add_labels_to_tokens(self, path:DocPath, tokens:JsonDict) -> JsonDict:
         apath = path
@@ -181,7 +211,15 @@ hash: {self._hashmark}, plus: {self._plus}")
         available = self._reader.is_available(path)
         logging.info(f"Cdocs._read_doc: {available}")
         if available:
-            content = self._reader.read(path, None)
+            content = self.reader.read(path)
+            #
+            #
+            #
+            if self.filer.is_probably_not_binary(path):
+                content = content.decode('utf-8')
+            #
+            #
+            #
             if content is None:
                 logging.warning(f"Cdocs._read_doc: cannot read {path}. returning None.")
         else:
@@ -192,8 +230,7 @@ hash: {self._hashmark}, plus: {self._plus}")
     def _get_dict(self, path:str, filename:str) -> JsonDict:
         path = path.strip('/\\')
         docroot = self.get_doc_root()
-        tf = DictFinder(docroot, path, filename)
-        return JsonDict(tf.get_tokens())
+        return JsonDict(self.finder.find_tokens(path, filename))
 
 
 
