@@ -1,11 +1,11 @@
-from cdocs.config import Config
+from cdocs.simple_config import SimpleConfig
 import unittest
 
 class ConfigTests(unittest.TestCase):
 
     def test_get_config_items(self):
         print(f"ConfigTests.test_get_config_items")
-        cfg = Config()
+        cfg = SimpleConfig()
         items = cfg.get_items("docs", ["public"])
         print(f"test_get_config_items: items: {items}")
         self.assertEqual( len(items), 2, msg="must be 2 items for docs" )
@@ -14,7 +14,7 @@ class ConfigTests(unittest.TestCase):
 
     def test_get_with_default(self):
         print(f"ConfigTests.test_get_with_default")
-        cfg = Config()
+        cfg = SimpleConfig()
         oh = cfg.get_with_default("fish", "bats", "yeah!")
         print(f"test_get_with_default: {oh}")
         self.assertEqual( oh, "yeah!", msg="must equal the default value" )
